# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EnvironmentArgs', 'Environment']

@pulumi.input_type
class EnvironmentArgs:
    def __init__(__self__, *,
                 environment_sub_type: pulumi.Input[str],
                 environment_type: pulumi.Input[str],
                 aliyun_lang: Optional[pulumi.Input[str]] = None,
                 bind_resource_id: Optional[pulumi.Input[str]] = None,
                 drop_metrics: Optional[pulumi.Input[str]] = None,
                 environment_name: Optional[pulumi.Input[str]] = None,
                 managed_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Environment resource.
        :param pulumi.Input[str] environment_sub_type: Subtype of environment:
               - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
               - Type of ECS: currently supports ECS.
               - Type of Cloud: currently supports Cloud.
        :param pulumi.Input[str] environment_type: Type of environment.
        :param pulumi.Input[str] aliyun_lang: The locale. The default is Chinese zh | en.
        :param pulumi.Input[str] bind_resource_id: The id or vpcId of the bound container instance.
        :param pulumi.Input[str] drop_metrics: List of abandoned indicators.
        :param pulumi.Input[str] environment_name: The name of the resource.
        :param pulumi.Input[str] managed_type: Hosting type:
               - none: unmanaged. The default value of the ACK cluster.
               - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
               - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource.
        """
        pulumi.set(__self__, "environment_sub_type", environment_sub_type)
        pulumi.set(__self__, "environment_type", environment_type)
        if aliyun_lang is not None:
            pulumi.set(__self__, "aliyun_lang", aliyun_lang)
        if bind_resource_id is not None:
            pulumi.set(__self__, "bind_resource_id", bind_resource_id)
        if drop_metrics is not None:
            pulumi.set(__self__, "drop_metrics", drop_metrics)
        if environment_name is not None:
            pulumi.set(__self__, "environment_name", environment_name)
        if managed_type is not None:
            pulumi.set(__self__, "managed_type", managed_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="environmentSubType")
    def environment_sub_type(self) -> pulumi.Input[str]:
        """
        Subtype of environment:
        - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
        - Type of ECS: currently supports ECS.
        - Type of Cloud: currently supports Cloud.
        """
        return pulumi.get(self, "environment_sub_type")

    @environment_sub_type.setter
    def environment_sub_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_sub_type", value)

    @property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> pulumi.Input[str]:
        """
        Type of environment.
        """
        return pulumi.get(self, "environment_type")

    @environment_type.setter
    def environment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_type", value)

    @property
    @pulumi.getter(name="aliyunLang")
    def aliyun_lang(self) -> Optional[pulumi.Input[str]]:
        """
        The locale. The default is Chinese zh | en.
        """
        return pulumi.get(self, "aliyun_lang")

    @aliyun_lang.setter
    def aliyun_lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aliyun_lang", value)

    @property
    @pulumi.getter(name="bindResourceId")
    def bind_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id or vpcId of the bound container instance.
        """
        return pulumi.get(self, "bind_resource_id")

    @bind_resource_id.setter
    def bind_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_resource_id", value)

    @property
    @pulumi.getter(name="dropMetrics")
    def drop_metrics(self) -> Optional[pulumi.Input[str]]:
        """
        List of abandoned indicators.
        """
        return pulumi.get(self, "drop_metrics")

    @drop_metrics.setter
    def drop_metrics(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "drop_metrics", value)

    @property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "environment_name")

    @environment_name.setter
    def environment_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_name", value)

    @property
    @pulumi.getter(name="managedType")
    def managed_type(self) -> Optional[pulumi.Input[str]]:
        """
        Hosting type:
        - none: unmanaged. The default value of the ACK cluster.
        - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
        - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        """
        return pulumi.get(self, "managed_type")

    @managed_type.setter
    def managed_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "managed_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _EnvironmentState:
    def __init__(__self__, *,
                 aliyun_lang: Optional[pulumi.Input[str]] = None,
                 bind_resource_id: Optional[pulumi.Input[str]] = None,
                 drop_metrics: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 environment_name: Optional[pulumi.Input[str]] = None,
                 environment_sub_type: Optional[pulumi.Input[str]] = None,
                 environment_type: Optional[pulumi.Input[str]] = None,
                 managed_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Environment resources.
        :param pulumi.Input[str] aliyun_lang: The locale. The default is Chinese zh | en.
        :param pulumi.Input[str] bind_resource_id: The id or vpcId of the bound container instance.
        :param pulumi.Input[str] drop_metrics: List of abandoned indicators.
        :param pulumi.Input[str] environment_id: The first ID of the resource.
        :param pulumi.Input[str] environment_name: The name of the resource.
        :param pulumi.Input[str] environment_sub_type: Subtype of environment:
               - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
               - Type of ECS: currently supports ECS.
               - Type of Cloud: currently supports Cloud.
        :param pulumi.Input[str] environment_type: Type of environment.
        :param pulumi.Input[str] managed_type: Hosting type:
               - none: unmanaged. The default value of the ACK cluster.
               - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
               - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource.
        """
        if aliyun_lang is not None:
            pulumi.set(__self__, "aliyun_lang", aliyun_lang)
        if bind_resource_id is not None:
            pulumi.set(__self__, "bind_resource_id", bind_resource_id)
        if drop_metrics is not None:
            pulumi.set(__self__, "drop_metrics", drop_metrics)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if environment_name is not None:
            pulumi.set(__self__, "environment_name", environment_name)
        if environment_sub_type is not None:
            pulumi.set(__self__, "environment_sub_type", environment_sub_type)
        if environment_type is not None:
            pulumi.set(__self__, "environment_type", environment_type)
        if managed_type is not None:
            pulumi.set(__self__, "managed_type", managed_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="aliyunLang")
    def aliyun_lang(self) -> Optional[pulumi.Input[str]]:
        """
        The locale. The default is Chinese zh | en.
        """
        return pulumi.get(self, "aliyun_lang")

    @aliyun_lang.setter
    def aliyun_lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aliyun_lang", value)

    @property
    @pulumi.getter(name="bindResourceId")
    def bind_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id or vpcId of the bound container instance.
        """
        return pulumi.get(self, "bind_resource_id")

    @bind_resource_id.setter
    def bind_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_resource_id", value)

    @property
    @pulumi.getter(name="dropMetrics")
    def drop_metrics(self) -> Optional[pulumi.Input[str]]:
        """
        List of abandoned indicators.
        """
        return pulumi.get(self, "drop_metrics")

    @drop_metrics.setter
    def drop_metrics(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "drop_metrics", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "environment_name")

    @environment_name.setter
    def environment_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_name", value)

    @property
    @pulumi.getter(name="environmentSubType")
    def environment_sub_type(self) -> Optional[pulumi.Input[str]]:
        """
        Subtype of environment:
        - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
        - Type of ECS: currently supports ECS.
        - Type of Cloud: currently supports Cloud.
        """
        return pulumi.get(self, "environment_sub_type")

    @environment_sub_type.setter
    def environment_sub_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_sub_type", value)

    @property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of environment.
        """
        return pulumi.get(self, "environment_type")

    @environment_type.setter
    def environment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_type", value)

    @property
    @pulumi.getter(name="managedType")
    def managed_type(self) -> Optional[pulumi.Input[str]]:
        """
        Hosting type:
        - none: unmanaged. The default value of the ACK cluster.
        - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
        - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        """
        return pulumi.get(self, "managed_type")

    @managed_type.setter
    def managed_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "managed_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class Environment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aliyun_lang: Optional[pulumi.Input[str]] = None,
                 bind_resource_id: Optional[pulumi.Input[str]] = None,
                 drop_metrics: Optional[pulumi.Input[str]] = None,
                 environment_name: Optional[pulumi.Input[str]] = None,
                 environment_sub_type: Optional[pulumi.Input[str]] = None,
                 environment_type: Optional[pulumi.Input[str]] = None,
                 managed_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a ARMS Environment resource. The arms environment.

        For information about ARMS Environment and how to use it, see [What is Environment](https://www.alibabacloud.com/help/en/arms/developer-reference/api-arms-2019-08-08-createenvironment).

        > **NOTE:** Available since v1.212.0.

        ## Import

        ARMS Environment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/environment:Environment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aliyun_lang: The locale. The default is Chinese zh | en.
        :param pulumi.Input[str] bind_resource_id: The id or vpcId of the bound container instance.
        :param pulumi.Input[str] drop_metrics: List of abandoned indicators.
        :param pulumi.Input[str] environment_name: The name of the resource.
        :param pulumi.Input[str] environment_sub_type: Subtype of environment:
               - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
               - Type of ECS: currently supports ECS.
               - Type of Cloud: currently supports Cloud.
        :param pulumi.Input[str] environment_type: Type of environment.
        :param pulumi.Input[str] managed_type: Hosting type:
               - none: unmanaged. The default value of the ACK cluster.
               - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
               - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ARMS Environment resource. The arms environment.

        For information about ARMS Environment and how to use it, see [What is Environment](https://www.alibabacloud.com/help/en/arms/developer-reference/api-arms-2019-08-08-createenvironment).

        > **NOTE:** Available since v1.212.0.

        ## Import

        ARMS Environment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/environment:Environment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aliyun_lang: Optional[pulumi.Input[str]] = None,
                 bind_resource_id: Optional[pulumi.Input[str]] = None,
                 drop_metrics: Optional[pulumi.Input[str]] = None,
                 environment_name: Optional[pulumi.Input[str]] = None,
                 environment_sub_type: Optional[pulumi.Input[str]] = None,
                 environment_type: Optional[pulumi.Input[str]] = None,
                 managed_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentArgs.__new__(EnvironmentArgs)

            __props__.__dict__["aliyun_lang"] = aliyun_lang
            __props__.__dict__["bind_resource_id"] = bind_resource_id
            __props__.__dict__["drop_metrics"] = drop_metrics
            __props__.__dict__["environment_name"] = environment_name
            if environment_sub_type is None and not opts.urn:
                raise TypeError("Missing required property 'environment_sub_type'")
            __props__.__dict__["environment_sub_type"] = environment_sub_type
            if environment_type is None and not opts.urn:
                raise TypeError("Missing required property 'environment_type'")
            __props__.__dict__["environment_type"] = environment_type
            __props__.__dict__["managed_type"] = managed_type
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["environment_id"] = None
        super(Environment, __self__).__init__(
            'alicloud:arms/environment:Environment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aliyun_lang: Optional[pulumi.Input[str]] = None,
            bind_resource_id: Optional[pulumi.Input[str]] = None,
            drop_metrics: Optional[pulumi.Input[str]] = None,
            environment_id: Optional[pulumi.Input[str]] = None,
            environment_name: Optional[pulumi.Input[str]] = None,
            environment_sub_type: Optional[pulumi.Input[str]] = None,
            environment_type: Optional[pulumi.Input[str]] = None,
            managed_type: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'Environment':
        """
        Get an existing Environment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aliyun_lang: The locale. The default is Chinese zh | en.
        :param pulumi.Input[str] bind_resource_id: The id or vpcId of the bound container instance.
        :param pulumi.Input[str] drop_metrics: List of abandoned indicators.
        :param pulumi.Input[str] environment_id: The first ID of the resource.
        :param pulumi.Input[str] environment_name: The name of the resource.
        :param pulumi.Input[str] environment_sub_type: Subtype of environment:
               - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
               - Type of ECS: currently supports ECS.
               - Type of Cloud: currently supports Cloud.
        :param pulumi.Input[str] environment_type: Type of environment.
        :param pulumi.Input[str] managed_type: Hosting type:
               - none: unmanaged. The default value of the ACK cluster.
               - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
               - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnvironmentState.__new__(_EnvironmentState)

        __props__.__dict__["aliyun_lang"] = aliyun_lang
        __props__.__dict__["bind_resource_id"] = bind_resource_id
        __props__.__dict__["drop_metrics"] = drop_metrics
        __props__.__dict__["environment_id"] = environment_id
        __props__.__dict__["environment_name"] = environment_name
        __props__.__dict__["environment_sub_type"] = environment_sub_type
        __props__.__dict__["environment_type"] = environment_type
        __props__.__dict__["managed_type"] = managed_type
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["tags"] = tags
        return Environment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aliyunLang")
    def aliyun_lang(self) -> pulumi.Output[Optional[str]]:
        """
        The locale. The default is Chinese zh | en.
        """
        return pulumi.get(self, "aliyun_lang")

    @property
    @pulumi.getter(name="bindResourceId")
    def bind_resource_id(self) -> pulumi.Output[Optional[str]]:
        """
        The id or vpcId of the bound container instance.
        """
        return pulumi.get(self, "bind_resource_id")

    @property
    @pulumi.getter(name="dropMetrics")
    def drop_metrics(self) -> pulumi.Output[Optional[str]]:
        """
        List of abandoned indicators.
        """
        return pulumi.get(self, "drop_metrics")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "environment_name")

    @property
    @pulumi.getter(name="environmentSubType")
    def environment_sub_type(self) -> pulumi.Output[str]:
        """
        Subtype of environment:
        - Type of CS: ACK is currently supported. ManagedKubernetes, Kubernetes, ExternalKubernetes, and One are also supported.
        - Type of ECS: currently supports ECS.
        - Type of Cloud: currently supports Cloud.
        """
        return pulumi.get(self, "environment_sub_type")

    @property
    @pulumi.getter(name="environmentType")
    def environment_type(self) -> pulumi.Output[str]:
        """
        Type of environment.
        """
        return pulumi.get(self, "environment_type")

    @property
    @pulumi.getter(name="managedType")
    def managed_type(self) -> pulumi.Output[str]:
        """
        Hosting type:
        - none: unmanaged. The default value of the ACK cluster.
        - agent: Managed agent (including ksm). Default values of ASK, ACS, and Acone clusters.
        - agent-exproter: Managed agent and exporter. The default value of the cloud service type.
        """
        return pulumi.get(self, "managed_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['JobTemplateArgs', 'JobTemplate']

@pulumi.input_type
class JobTemplateArgs:
    def __init__(__self__, *,
                 command_line: pulumi.Input[str],
                 job_template_name: pulumi.Input[str],
                 array_request: Optional[pulumi.Input[str]] = None,
                 clock_time: Optional[pulumi.Input[str]] = None,
                 gpu: Optional[pulumi.Input[int]] = None,
                 mem: Optional[pulumi.Input[str]] = None,
                 node: Optional[pulumi.Input[int]] = None,
                 package_path: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 queue: Optional[pulumi.Input[str]] = None,
                 re_runable: Optional[pulumi.Input[bool]] = None,
                 runas_user: Optional[pulumi.Input[str]] = None,
                 stderr_redirect_path: Optional[pulumi.Input[str]] = None,
                 stdout_redirect_path: Optional[pulumi.Input[str]] = None,
                 task: Optional[pulumi.Input[int]] = None,
                 thread: Optional[pulumi.Input[int]] = None,
                 variables: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a JobTemplate resource.
        :param pulumi.Input[str] command_line: Job Commands.
        :param pulumi.Input[str] job_template_name: A Job Template Name.
        :param pulumi.Input[str] array_request: Queue Jobs, Is of the Form: 1-10:2.
        :param pulumi.Input[str] clock_time: Job Maximum Run Time.
        :param pulumi.Input[int] gpu: A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        :param pulumi.Input[str] mem: A Single Compute Node Maximum Memory.
        :param pulumi.Input[int] node: Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        :param pulumi.Input[str] package_path: Job Commands the Directory.
        :param pulumi.Input[int] priority: The Job Priority.
        :param pulumi.Input[str] queue: The Job Queue.
        :param pulumi.Input[bool] re_runable: If the Job Is Support for the Re-Run.
        :param pulumi.Input[str] runas_user: The name of the user who performed the job.
        :param pulumi.Input[str] stderr_redirect_path: Error Output Path.
        :param pulumi.Input[str] stdout_redirect_path: Standard Output Path and.
        :param pulumi.Input[int] task: A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        :param pulumi.Input[int] thread: A Single Task and the Number of Required Threads.
        :param pulumi.Input[str] variables: The Job of the Environment Variable.
        """
        pulumi.set(__self__, "command_line", command_line)
        pulumi.set(__self__, "job_template_name", job_template_name)
        if array_request is not None:
            pulumi.set(__self__, "array_request", array_request)
        if clock_time is not None:
            pulumi.set(__self__, "clock_time", clock_time)
        if gpu is not None:
            pulumi.set(__self__, "gpu", gpu)
        if mem is not None:
            pulumi.set(__self__, "mem", mem)
        if node is not None:
            pulumi.set(__self__, "node", node)
        if package_path is not None:
            pulumi.set(__self__, "package_path", package_path)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if queue is not None:
            pulumi.set(__self__, "queue", queue)
        if re_runable is not None:
            pulumi.set(__self__, "re_runable", re_runable)
        if runas_user is not None:
            pulumi.set(__self__, "runas_user", runas_user)
        if stderr_redirect_path is not None:
            pulumi.set(__self__, "stderr_redirect_path", stderr_redirect_path)
        if stdout_redirect_path is not None:
            pulumi.set(__self__, "stdout_redirect_path", stdout_redirect_path)
        if task is not None:
            pulumi.set(__self__, "task", task)
        if thread is not None:
            pulumi.set(__self__, "thread", thread)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="commandLine")
    def command_line(self) -> pulumi.Input[str]:
        """
        Job Commands.
        """
        return pulumi.get(self, "command_line")

    @command_line.setter
    def command_line(self, value: pulumi.Input[str]):
        pulumi.set(self, "command_line", value)

    @property
    @pulumi.getter(name="jobTemplateName")
    def job_template_name(self) -> pulumi.Input[str]:
        """
        A Job Template Name.
        """
        return pulumi.get(self, "job_template_name")

    @job_template_name.setter
    def job_template_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "job_template_name", value)

    @property
    @pulumi.getter(name="arrayRequest")
    def array_request(self) -> Optional[pulumi.Input[str]]:
        """
        Queue Jobs, Is of the Form: 1-10:2.
        """
        return pulumi.get(self, "array_request")

    @array_request.setter
    def array_request(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "array_request", value)

    @property
    @pulumi.getter(name="clockTime")
    def clock_time(self) -> Optional[pulumi.Input[str]]:
        """
        Job Maximum Run Time.
        """
        return pulumi.get(self, "clock_time")

    @clock_time.setter
    def clock_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clock_time", value)

    @property
    @pulumi.getter
    def gpu(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        """
        return pulumi.get(self, "gpu")

    @gpu.setter
    def gpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gpu", value)

    @property
    @pulumi.getter
    def mem(self) -> Optional[pulumi.Input[str]]:
        """
        A Single Compute Node Maximum Memory.
        """
        return pulumi.get(self, "mem")

    @mem.setter
    def mem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mem", value)

    @property
    @pulumi.getter
    def node(self) -> Optional[pulumi.Input[int]]:
        """
        Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        """
        return pulumi.get(self, "node")

    @node.setter
    def node(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node", value)

    @property
    @pulumi.getter(name="packagePath")
    def package_path(self) -> Optional[pulumi.Input[str]]:
        """
        Job Commands the Directory.
        """
        return pulumi.get(self, "package_path")

    @package_path.setter
    def package_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_path", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The Job Priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def queue(self) -> Optional[pulumi.Input[str]]:
        """
        The Job Queue.
        """
        return pulumi.get(self, "queue")

    @queue.setter
    def queue(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue", value)

    @property
    @pulumi.getter(name="reRunable")
    def re_runable(self) -> Optional[pulumi.Input[bool]]:
        """
        If the Job Is Support for the Re-Run.
        """
        return pulumi.get(self, "re_runable")

    @re_runable.setter
    def re_runable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "re_runable", value)

    @property
    @pulumi.getter(name="runasUser")
    def runas_user(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user who performed the job.
        """
        return pulumi.get(self, "runas_user")

    @runas_user.setter
    def runas_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "runas_user", value)

    @property
    @pulumi.getter(name="stderrRedirectPath")
    def stderr_redirect_path(self) -> Optional[pulumi.Input[str]]:
        """
        Error Output Path.
        """
        return pulumi.get(self, "stderr_redirect_path")

    @stderr_redirect_path.setter
    def stderr_redirect_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stderr_redirect_path", value)

    @property
    @pulumi.getter(name="stdoutRedirectPath")
    def stdout_redirect_path(self) -> Optional[pulumi.Input[str]]:
        """
        Standard Output Path and.
        """
        return pulumi.get(self, "stdout_redirect_path")

    @stdout_redirect_path.setter
    def stdout_redirect_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stdout_redirect_path", value)

    @property
    @pulumi.getter
    def task(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        """
        return pulumi.get(self, "task")

    @task.setter
    def task(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "task", value)

    @property
    @pulumi.getter
    def thread(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Task and the Number of Required Threads.
        """
        return pulumi.get(self, "thread")

    @thread.setter
    def thread(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "thread", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[str]]:
        """
        The Job of the Environment Variable.
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class _JobTemplateState:
    def __init__(__self__, *,
                 array_request: Optional[pulumi.Input[str]] = None,
                 clock_time: Optional[pulumi.Input[str]] = None,
                 command_line: Optional[pulumi.Input[str]] = None,
                 gpu: Optional[pulumi.Input[int]] = None,
                 job_template_name: Optional[pulumi.Input[str]] = None,
                 mem: Optional[pulumi.Input[str]] = None,
                 node: Optional[pulumi.Input[int]] = None,
                 package_path: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 queue: Optional[pulumi.Input[str]] = None,
                 re_runable: Optional[pulumi.Input[bool]] = None,
                 runas_user: Optional[pulumi.Input[str]] = None,
                 stderr_redirect_path: Optional[pulumi.Input[str]] = None,
                 stdout_redirect_path: Optional[pulumi.Input[str]] = None,
                 task: Optional[pulumi.Input[int]] = None,
                 thread: Optional[pulumi.Input[int]] = None,
                 variables: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering JobTemplate resources.
        :param pulumi.Input[str] array_request: Queue Jobs, Is of the Form: 1-10:2.
        :param pulumi.Input[str] clock_time: Job Maximum Run Time.
        :param pulumi.Input[str] command_line: Job Commands.
        :param pulumi.Input[int] gpu: A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        :param pulumi.Input[str] job_template_name: A Job Template Name.
        :param pulumi.Input[str] mem: A Single Compute Node Maximum Memory.
        :param pulumi.Input[int] node: Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        :param pulumi.Input[str] package_path: Job Commands the Directory.
        :param pulumi.Input[int] priority: The Job Priority.
        :param pulumi.Input[str] queue: The Job Queue.
        :param pulumi.Input[bool] re_runable: If the Job Is Support for the Re-Run.
        :param pulumi.Input[str] runas_user: The name of the user who performed the job.
        :param pulumi.Input[str] stderr_redirect_path: Error Output Path.
        :param pulumi.Input[str] stdout_redirect_path: Standard Output Path and.
        :param pulumi.Input[int] task: A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        :param pulumi.Input[int] thread: A Single Task and the Number of Required Threads.
        :param pulumi.Input[str] variables: The Job of the Environment Variable.
        """
        if array_request is not None:
            pulumi.set(__self__, "array_request", array_request)
        if clock_time is not None:
            pulumi.set(__self__, "clock_time", clock_time)
        if command_line is not None:
            pulumi.set(__self__, "command_line", command_line)
        if gpu is not None:
            pulumi.set(__self__, "gpu", gpu)
        if job_template_name is not None:
            pulumi.set(__self__, "job_template_name", job_template_name)
        if mem is not None:
            pulumi.set(__self__, "mem", mem)
        if node is not None:
            pulumi.set(__self__, "node", node)
        if package_path is not None:
            pulumi.set(__self__, "package_path", package_path)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if queue is not None:
            pulumi.set(__self__, "queue", queue)
        if re_runable is not None:
            pulumi.set(__self__, "re_runable", re_runable)
        if runas_user is not None:
            pulumi.set(__self__, "runas_user", runas_user)
        if stderr_redirect_path is not None:
            pulumi.set(__self__, "stderr_redirect_path", stderr_redirect_path)
        if stdout_redirect_path is not None:
            pulumi.set(__self__, "stdout_redirect_path", stdout_redirect_path)
        if task is not None:
            pulumi.set(__self__, "task", task)
        if thread is not None:
            pulumi.set(__self__, "thread", thread)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="arrayRequest")
    def array_request(self) -> Optional[pulumi.Input[str]]:
        """
        Queue Jobs, Is of the Form: 1-10:2.
        """
        return pulumi.get(self, "array_request")

    @array_request.setter
    def array_request(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "array_request", value)

    @property
    @pulumi.getter(name="clockTime")
    def clock_time(self) -> Optional[pulumi.Input[str]]:
        """
        Job Maximum Run Time.
        """
        return pulumi.get(self, "clock_time")

    @clock_time.setter
    def clock_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clock_time", value)

    @property
    @pulumi.getter(name="commandLine")
    def command_line(self) -> Optional[pulumi.Input[str]]:
        """
        Job Commands.
        """
        return pulumi.get(self, "command_line")

    @command_line.setter
    def command_line(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command_line", value)

    @property
    @pulumi.getter
    def gpu(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        """
        return pulumi.get(self, "gpu")

    @gpu.setter
    def gpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gpu", value)

    @property
    @pulumi.getter(name="jobTemplateName")
    def job_template_name(self) -> Optional[pulumi.Input[str]]:
        """
        A Job Template Name.
        """
        return pulumi.get(self, "job_template_name")

    @job_template_name.setter
    def job_template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_template_name", value)

    @property
    @pulumi.getter
    def mem(self) -> Optional[pulumi.Input[str]]:
        """
        A Single Compute Node Maximum Memory.
        """
        return pulumi.get(self, "mem")

    @mem.setter
    def mem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mem", value)

    @property
    @pulumi.getter
    def node(self) -> Optional[pulumi.Input[int]]:
        """
        Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        """
        return pulumi.get(self, "node")

    @node.setter
    def node(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node", value)

    @property
    @pulumi.getter(name="packagePath")
    def package_path(self) -> Optional[pulumi.Input[str]]:
        """
        Job Commands the Directory.
        """
        return pulumi.get(self, "package_path")

    @package_path.setter
    def package_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_path", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The Job Priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def queue(self) -> Optional[pulumi.Input[str]]:
        """
        The Job Queue.
        """
        return pulumi.get(self, "queue")

    @queue.setter
    def queue(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue", value)

    @property
    @pulumi.getter(name="reRunable")
    def re_runable(self) -> Optional[pulumi.Input[bool]]:
        """
        If the Job Is Support for the Re-Run.
        """
        return pulumi.get(self, "re_runable")

    @re_runable.setter
    def re_runable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "re_runable", value)

    @property
    @pulumi.getter(name="runasUser")
    def runas_user(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user who performed the job.
        """
        return pulumi.get(self, "runas_user")

    @runas_user.setter
    def runas_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "runas_user", value)

    @property
    @pulumi.getter(name="stderrRedirectPath")
    def stderr_redirect_path(self) -> Optional[pulumi.Input[str]]:
        """
        Error Output Path.
        """
        return pulumi.get(self, "stderr_redirect_path")

    @stderr_redirect_path.setter
    def stderr_redirect_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stderr_redirect_path", value)

    @property
    @pulumi.getter(name="stdoutRedirectPath")
    def stdout_redirect_path(self) -> Optional[pulumi.Input[str]]:
        """
        Standard Output Path and.
        """
        return pulumi.get(self, "stdout_redirect_path")

    @stdout_redirect_path.setter
    def stdout_redirect_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stdout_redirect_path", value)

    @property
    @pulumi.getter
    def task(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        """
        return pulumi.get(self, "task")

    @task.setter
    def task(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "task", value)

    @property
    @pulumi.getter
    def thread(self) -> Optional[pulumi.Input[int]]:
        """
        A Single Task and the Number of Required Threads.
        """
        return pulumi.get(self, "thread")

    @thread.setter
    def thread(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "thread", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[str]]:
        """
        The Job of the Environment Variable.
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "variables", value)


class JobTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 array_request: Optional[pulumi.Input[str]] = None,
                 clock_time: Optional[pulumi.Input[str]] = None,
                 command_line: Optional[pulumi.Input[str]] = None,
                 gpu: Optional[pulumi.Input[int]] = None,
                 job_template_name: Optional[pulumi.Input[str]] = None,
                 mem: Optional[pulumi.Input[str]] = None,
                 node: Optional[pulumi.Input[int]] = None,
                 package_path: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 queue: Optional[pulumi.Input[str]] = None,
                 re_runable: Optional[pulumi.Input[bool]] = None,
                 runas_user: Optional[pulumi.Input[str]] = None,
                 stderr_redirect_path: Optional[pulumi.Input[str]] = None,
                 stdout_redirect_path: Optional[pulumi.Input[str]] = None,
                 task: Optional[pulumi.Input[int]] = None,
                 thread: Optional[pulumi.Input[int]] = None,
                 variables: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Ehpc Job Template resource.

        For information about Ehpc Job Template and how to use it, see [What is Job Template](https://www.alibabacloud.com/help/product/57664.html).

        > **NOTE:** Available since v1.133.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ehpc.JobTemplate("default",
            job_template_name="example_value",
            command_line="./LammpsTest/lammps.pbs")
        ```

        ## Import

        Ehpc Job Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ehpc/jobTemplate:JobTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] array_request: Queue Jobs, Is of the Form: 1-10:2.
        :param pulumi.Input[str] clock_time: Job Maximum Run Time.
        :param pulumi.Input[str] command_line: Job Commands.
        :param pulumi.Input[int] gpu: A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        :param pulumi.Input[str] job_template_name: A Job Template Name.
        :param pulumi.Input[str] mem: A Single Compute Node Maximum Memory.
        :param pulumi.Input[int] node: Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        :param pulumi.Input[str] package_path: Job Commands the Directory.
        :param pulumi.Input[int] priority: The Job Priority.
        :param pulumi.Input[str] queue: The Job Queue.
        :param pulumi.Input[bool] re_runable: If the Job Is Support for the Re-Run.
        :param pulumi.Input[str] runas_user: The name of the user who performed the job.
        :param pulumi.Input[str] stderr_redirect_path: Error Output Path.
        :param pulumi.Input[str] stdout_redirect_path: Standard Output Path and.
        :param pulumi.Input[int] task: A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        :param pulumi.Input[int] thread: A Single Task and the Number of Required Threads.
        :param pulumi.Input[str] variables: The Job of the Environment Variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Ehpc Job Template resource.

        For information about Ehpc Job Template and how to use it, see [What is Job Template](https://www.alibabacloud.com/help/product/57664.html).

        > **NOTE:** Available since v1.133.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ehpc.JobTemplate("default",
            job_template_name="example_value",
            command_line="./LammpsTest/lammps.pbs")
        ```

        ## Import

        Ehpc Job Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ehpc/jobTemplate:JobTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param JobTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 array_request: Optional[pulumi.Input[str]] = None,
                 clock_time: Optional[pulumi.Input[str]] = None,
                 command_line: Optional[pulumi.Input[str]] = None,
                 gpu: Optional[pulumi.Input[int]] = None,
                 job_template_name: Optional[pulumi.Input[str]] = None,
                 mem: Optional[pulumi.Input[str]] = None,
                 node: Optional[pulumi.Input[int]] = None,
                 package_path: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 queue: Optional[pulumi.Input[str]] = None,
                 re_runable: Optional[pulumi.Input[bool]] = None,
                 runas_user: Optional[pulumi.Input[str]] = None,
                 stderr_redirect_path: Optional[pulumi.Input[str]] = None,
                 stdout_redirect_path: Optional[pulumi.Input[str]] = None,
                 task: Optional[pulumi.Input[int]] = None,
                 thread: Optional[pulumi.Input[int]] = None,
                 variables: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobTemplateArgs.__new__(JobTemplateArgs)

            __props__.__dict__["array_request"] = array_request
            __props__.__dict__["clock_time"] = clock_time
            if command_line is None and not opts.urn:
                raise TypeError("Missing required property 'command_line'")
            __props__.__dict__["command_line"] = command_line
            __props__.__dict__["gpu"] = gpu
            if job_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'job_template_name'")
            __props__.__dict__["job_template_name"] = job_template_name
            __props__.__dict__["mem"] = mem
            __props__.__dict__["node"] = node
            __props__.__dict__["package_path"] = package_path
            __props__.__dict__["priority"] = priority
            __props__.__dict__["queue"] = queue
            __props__.__dict__["re_runable"] = re_runable
            __props__.__dict__["runas_user"] = runas_user
            __props__.__dict__["stderr_redirect_path"] = stderr_redirect_path
            __props__.__dict__["stdout_redirect_path"] = stdout_redirect_path
            __props__.__dict__["task"] = task
            __props__.__dict__["thread"] = thread
            __props__.__dict__["variables"] = variables
        super(JobTemplate, __self__).__init__(
            'alicloud:ehpc/jobTemplate:JobTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            array_request: Optional[pulumi.Input[str]] = None,
            clock_time: Optional[pulumi.Input[str]] = None,
            command_line: Optional[pulumi.Input[str]] = None,
            gpu: Optional[pulumi.Input[int]] = None,
            job_template_name: Optional[pulumi.Input[str]] = None,
            mem: Optional[pulumi.Input[str]] = None,
            node: Optional[pulumi.Input[int]] = None,
            package_path: Optional[pulumi.Input[str]] = None,
            priority: Optional[pulumi.Input[int]] = None,
            queue: Optional[pulumi.Input[str]] = None,
            re_runable: Optional[pulumi.Input[bool]] = None,
            runas_user: Optional[pulumi.Input[str]] = None,
            stderr_redirect_path: Optional[pulumi.Input[str]] = None,
            stdout_redirect_path: Optional[pulumi.Input[str]] = None,
            task: Optional[pulumi.Input[int]] = None,
            thread: Optional[pulumi.Input[int]] = None,
            variables: Optional[pulumi.Input[str]] = None) -> 'JobTemplate':
        """
        Get an existing JobTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] array_request: Queue Jobs, Is of the Form: 1-10:2.
        :param pulumi.Input[str] clock_time: Job Maximum Run Time.
        :param pulumi.Input[str] command_line: Job Commands.
        :param pulumi.Input[int] gpu: A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        :param pulumi.Input[str] job_template_name: A Job Template Name.
        :param pulumi.Input[str] mem: A Single Compute Node Maximum Memory.
        :param pulumi.Input[int] node: Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        :param pulumi.Input[str] package_path: Job Commands the Directory.
        :param pulumi.Input[int] priority: The Job Priority.
        :param pulumi.Input[str] queue: The Job Queue.
        :param pulumi.Input[bool] re_runable: If the Job Is Support for the Re-Run.
        :param pulumi.Input[str] runas_user: The name of the user who performed the job.
        :param pulumi.Input[str] stderr_redirect_path: Error Output Path.
        :param pulumi.Input[str] stdout_redirect_path: Standard Output Path and.
        :param pulumi.Input[int] task: A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        :param pulumi.Input[int] thread: A Single Task and the Number of Required Threads.
        :param pulumi.Input[str] variables: The Job of the Environment Variable.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobTemplateState.__new__(_JobTemplateState)

        __props__.__dict__["array_request"] = array_request
        __props__.__dict__["clock_time"] = clock_time
        __props__.__dict__["command_line"] = command_line
        __props__.__dict__["gpu"] = gpu
        __props__.__dict__["job_template_name"] = job_template_name
        __props__.__dict__["mem"] = mem
        __props__.__dict__["node"] = node
        __props__.__dict__["package_path"] = package_path
        __props__.__dict__["priority"] = priority
        __props__.__dict__["queue"] = queue
        __props__.__dict__["re_runable"] = re_runable
        __props__.__dict__["runas_user"] = runas_user
        __props__.__dict__["stderr_redirect_path"] = stderr_redirect_path
        __props__.__dict__["stdout_redirect_path"] = stdout_redirect_path
        __props__.__dict__["task"] = task
        __props__.__dict__["thread"] = thread
        __props__.__dict__["variables"] = variables
        return JobTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="arrayRequest")
    def array_request(self) -> pulumi.Output[Optional[str]]:
        """
        Queue Jobs, Is of the Form: 1-10:2.
        """
        return pulumi.get(self, "array_request")

    @property
    @pulumi.getter(name="clockTime")
    def clock_time(self) -> pulumi.Output[Optional[str]]:
        """
        Job Maximum Run Time.
        """
        return pulumi.get(self, "clock_time")

    @property
    @pulumi.getter(name="commandLine")
    def command_line(self) -> pulumi.Output[str]:
        """
        Job Commands.
        """
        return pulumi.get(self, "command_line")

    @property
    @pulumi.getter
    def gpu(self) -> pulumi.Output[Optional[int]]:
        """
        A Single Compute Node Using the GPU Number.Possible Values: 1~20000.
        """
        return pulumi.get(self, "gpu")

    @property
    @pulumi.getter(name="jobTemplateName")
    def job_template_name(self) -> pulumi.Output[str]:
        """
        A Job Template Name.
        """
        return pulumi.get(self, "job_template_name")

    @property
    @pulumi.getter
    def mem(self) -> pulumi.Output[Optional[str]]:
        """
        A Single Compute Node Maximum Memory.
        """
        return pulumi.get(self, "mem")

    @property
    @pulumi.getter
    def node(self) -> pulumi.Output[Optional[int]]:
        """
        Submit a Task Is Required for Computing the Number of Data Nodes to Be. Possible Values: 1~5000 .
        """
        return pulumi.get(self, "node")

    @property
    @pulumi.getter(name="packagePath")
    def package_path(self) -> pulumi.Output[Optional[str]]:
        """
        Job Commands the Directory.
        """
        return pulumi.get(self, "package_path")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[int]]:
        """
        The Job Priority.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def queue(self) -> pulumi.Output[Optional[str]]:
        """
        The Job Queue.
        """
        return pulumi.get(self, "queue")

    @property
    @pulumi.getter(name="reRunable")
    def re_runable(self) -> pulumi.Output[bool]:
        """
        If the Job Is Support for the Re-Run.
        """
        return pulumi.get(self, "re_runable")

    @property
    @pulumi.getter(name="runasUser")
    def runas_user(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the user who performed the job.
        """
        return pulumi.get(self, "runas_user")

    @property
    @pulumi.getter(name="stderrRedirectPath")
    def stderr_redirect_path(self) -> pulumi.Output[Optional[str]]:
        """
        Error Output Path.
        """
        return pulumi.get(self, "stderr_redirect_path")

    @property
    @pulumi.getter(name="stdoutRedirectPath")
    def stdout_redirect_path(self) -> pulumi.Output[Optional[str]]:
        """
        Standard Output Path and.
        """
        return pulumi.get(self, "stdout_redirect_path")

    @property
    @pulumi.getter
    def task(self) -> pulumi.Output[Optional[int]]:
        """
        A Single Compute Node Required Number of Tasks. Possible Values: 1~20000 .
        """
        return pulumi.get(self, "task")

    @property
    @pulumi.getter
    def thread(self) -> pulumi.Output[Optional[int]]:
        """
        A Single Task and the Number of Required Threads.
        """
        return pulumi.get(self, "thread")

    @property
    @pulumi.getter
    def variables(self) -> pulumi.Output[Optional[str]]:
        """
        The Job of the Environment Variable.
        """
        return pulumi.get(self, "variables")

